SoCo 0.26 Release Notes
***********************

**SoCo 0.26.0** (Released on 2022-01-24), contains new features as well as
internal improvements.

In particular this release reintroduces **experimental** support for music
services. Testing and issue reporting would be appreciated.

Please see the GitHub release page for further details:
https://github.com/SoCo/SoCo/releases/tag/v0.26.0
